==> qt-creator-opensource-src-4.0.3.zip: qt-creator-opensource-src-4.0.3/src/plugins/clangcodemodel/test/clangcodecompletion_test.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef CLANGCODECOMPLETIONTEST_H
#define CLANGCODECOMPLETIONTEST_H

#include <QObject>

namespace ClangCodeModel {
namespace Internal {
namespace Tests {

class ActivateClangModelManagerSupport;

class ClangCodeCompletionTest : public QObject
{
    Q_OBJECT

private slots:
    void testCompleteDoxygenKeywords();
    void testCompletePreprocessorKeywords();
    void testCompleteIncludeDirective();

    void testCompleteGlobals();
    void testCompleteMembers();
    void testCompleteFunctions();
    void testCompleteConstructorAndFallbackToGlobalCompletion();

    void testCompleteWithDotToArrowCorrection();
    void testDontCompleteWithDotToArrowCorrectionForFloats();

    void testCompleteProjectDependingCode();
    void testCompleteProjectDependingCodeAfterChangingProject();
    void testCompleteProjectDependingCodeInGeneratedUiFile();

    void testCompleteAfterModifyingIncludedHeaderInOtherEditor();
    void testCompleteAfterModifyingIncludedHeaderByRefactoringActions();
    void testCompleteAfterChangingIncludedAndOpenHeaderExternally();
    void testCompleteAfterChangingIncludedAndNotOpenHeaderExternally();

    void testUpdateBackendAfterRestart();
};

} // namespace Tests
} // namespace Internal
} // namespace ClangCodeModel

#endif // CLANGCODECOMPLETIONTEST_H

==> qt-creator-opensource-src-4.10.1.zip: qt-creator-opensource-src-4.10.1/src/plugins/clangcodemodel/test/clangcodecompletion_test.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <QObject>

namespace ClangCodeModel {
namespace Internal {
namespace Tests {

class ActivateClangModelManagerSupport;

class ClangCodeCompletionTest : public QObject
{
    Q_OBJECT

private slots:
    void testCompleteDoxygenKeywords();
    void testCompletePreprocessorKeywords();
    void testCompleteIncludeDirective();

    void testCompleteGlobals();
    void testCompleteMembers();
    void testCompleteFunctions();
    void testCompleteConstructor();
    void testCompleteClassAndConstructor();

    void testCompleteWithDotToArrowCorrection();
    void testDontCompleteWithDotToArrowCorrectionForFloats();

    void testCompleteProjectDependingCode();
    void testCompleteProjectDependingCodeAfterChangingProject();
    void testCompleteProjectDependingCodeInGeneratedUiFile();
};

} // namespace Tests
} // namespace Internal
} // namespace ClangCodeModel
